---
name: Bug report
about: Create a report to help us reproduce the bug
title: "[BUG]"
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is. Please provide error messages (use screenshot if it helps).

**Steps To Reproduce**
Please add a minimal example/commands run to reproduce bug

**Expected behavior**
A clear and concise description of what you expected to happen.


**Your Environment**
- Operating System
- Piplexed version used (run `piplexed version`)
- Python version used
- pipx or uv version
   - pipx: run `pipx --version`
   - uv: run `uv version`
